@@ -1,6 +1,5 @@
-from typing import Generator, Optional, List, Dict, Union, IO
-from ..api import chat_stream_api, get_chat_history_api, get_jwt_token_api
-
+from typing import Generator, Optional, List, Dict, Union, IO, Any
+from ..api.ChatApi import chat_stream_api, get_chat_history_api, get_jwt_token_api
 
 class ChatClient:
     def __init__(self, agent_id: str, personal_auth_key: str, personal_auth_secret: str, base_url: str = "https://uat.agentspro.cn"):
@@ -27,7 +26,7 @@ class ChatClient:
                 - 私有部署时可指定自定义地址
         """
         self.agent_id = agent_id
-        self.jwt_token = get_jwt_token_api(personal_auth_key, personal_auth_key, base_url) 
+        self.jwt_token = get_jwt_token_api(personal_auth_key, personal_auth_secret, base_url) 
         self.base_url = base_url
         self.chat_id = None
 
@@ -39,110 +38,48 @@ class ChatClient:
         state: Optional[Dict[str, str]] = None,
         button_key: Optional[str] = None,
         debug: bool = False,
-    ) -> Generator[str, None, None]:
+    ) -> Generator[Dict[str, Any], None, None]:
         """
-        发起对话请求并获取流式响应
-        
-        向 AI Agent 发送消息并获取实时的流式回复。支持文本、图片、文件等多种输入类型。
-        
+        发起对话，以结构化事件流方式返回响应。
+
+        这是与 Agent 交互的唯一方法，它通过产生结构化事件，使得前端可以同时实现
+        多气泡和每个气泡的打字机效果，同时还支持显示 AI 的推理过程。
+
         Args:
-            prompt (str): 用户输入的对话内容
-                - 必填参数，用户要发送给 AI 的文本消息
-                
-            images (List[str], optional): 图片 URL 列表
-                - 可选参数，默认为 None
-                - 每个元素为图片的 HTTP/HTTPS URL 地址
-                - 支持常见图片格式：JPEG, PNG, GIF, WebP 等
-                - 示例: ["https://example.com/image1.jpg", "https://example.com/image2.png"]
-                
-            files (List[Union[str, IO]], optional): 文件列表
-                - 可选参数，默认为 None
-                - 支持两种类型：
-                  1. 文件路径字符串：如 "/path/to/document.pdf"
-                  2. 文件对象：如 open("file.txt", "rb") 或 BytesIO 对象
-                - 支持文件类型：PDF, TXT, DOC, DOCX, XLS, XLSX, PPT, PPTX 等
-                - 文件会自动上传并在对话中引用
-                - 示例: ["./report.pdf", open("data.xlsx", "rb")]
-                
-            state (Dict[str, str], optional): 对话状态参数
-                - 可选参数，默认为 None
-                - 用于传递额外的上下文信息或配置参数
-                - 键值对格式，所有值都必须是字符串类型
-                - 示例: {"language": "zh-CN", "format": "markdown"}
-                
-            button_key (str, optional): 按钮键值
-                - 可选参数，默认为 None  
-                - 用于触发特定的按钮操作或工作流
-                - 通常在 Agent 配置了交互按钮时使用
-                - 示例: "analyze_button", "summarize_action"
-                
-            debug (bool, optional): 调试模式
-                - 可选参数，默认为 False
-                - 启用时会返回更详细的调试信息
-                - 用于开发和故障排查
-                
-        Returns:
-            Generator[str, None, None]: 流式响应生成器
-                - 生成器对象，逐步产出 AI 的回复内容
-                - 每次 yield 返回一个字符串片段
-                - 可通过 for 循环实时获取响应内容
-                
+            prompt (str): 用户输入的对话内容。
+            images (List[str], optional): 图片 URL 列表。
+            files (List[Union[str, IO]], optional): 文件列表。
+            state (Dict[str, str], optional): 对话状态参数。
+            button_key (str, optional): 按钮键值。
+            debug (bool, optional): 调试模式。
+
+        Yields:
+            Dict[str, Any]: 一个包含事件类型和数据的字典。
+                - `{'type': 'start_bubble', 'bubble_id': int}`: 标志着一个新的回复气泡开始。
+                - `{'type': 'token', 'content': str}`: 当前气泡内的一个文本片段（用于打字机效果）。
+                - `{'type': 'reasoning_token', 'content': str}`: AI 推理过程的文本片段。
+                - `{'type': 'end_bubble'}`: 标志着当前回复气泡结束。
+                - `{'type': 'finish'}`: 标志着整个对话回合结束。
+        
         示例:
-            Example 1: 基础文本对话
             .. code-block:: python
 
-                from autoagentsai.client import ChatClient
-                client = ChatClient(agent_id="your_agent_id", personal_auth_key="your_personal_auth_key", personal_auth_secret="your_personal_auth_secret")
-                for chunk in client.invoke("你好"):
-                    print(chunk, end="", flush=True)
-            
-            Example 2: 上传本地文件并分析
-
-            .. code-block:: python
-
-                from autoagentsai.uploader import create_file_like
-                file_obj = create_file_like("./document.pdf")
-                for chunk in client.invoke("请分析这个文档", files=[file_obj]):
-                    print(chunk, end="", flush=True)
-            
-            Example 3: 处理前端上传的文件并分析
-
-            .. code-block:: python
-
-                from fastapi import FastAPI, UploadFile
-                from src.autoagentsai.client import ChatClient
-                from src.autoagentsai.uploader import create_file_like
-
-                app = FastAPI()
-                client = ChatClient(agent_id="xxx", personal_auth_key="xxx", personel_auth_secret="xxx")
-
-                @app.post("/analyze")
-                async def analyze_file(file: UploadFile = File(...)):
-                    # 读取前端上传的文件
-                    content = await file.read()
-                    file_obj = create_file_like(content, filename=file.filename)
-                    
-                    # 调用 AI 分析
-                    response = ""
-                    for chunk in client.invoke("分析这个文件", files=[file_obj]):
-                        response += chunk
-                        
-                    return {"result": response}
-
-            Example 4: 多模态输入
-
-            .. code-block:: python
-
-                from autoagentsai.client import ChatClient
-                client = ChatClient(agent_id="your_agent_id", personal_auth_key="your_personal_auth_key", personal_auth_secret="your_personal_auth_secret")
-                for chunk in client.invoke(
-                    prompt="分析这张图片和文档",
-                    images=["https://example.com/chart.png"],
-                    files=["./data.xlsx"]
-                ):
-                    print(chunk, end="", flush=True)
+                for event in client.invoke("写一首关于AI的诗"):
+                    if event['type'] == 'start_bubble':
+                        print(f"\\n--- 新气泡 {event['bubble_id']} ---")
+                    elif event['type'] == 'token':
+                        print(event['content'], end="")
+                    elif event['type'] == 'reasoning_token':
+                        print(f"[推理: {event['content']}]", end="")
+                    elif event['type'] == 'end_bubble':
+                        print("\\n--- 气泡结束 ---")
+                    elif event['type'] == 'finish':
+                        print("\\n\\n对话完成。")
         """
-        for content, chat_id in chat_stream_api(
+        current_reply = ""
+        bubble_id_counter = 0
+
+        api_stream = chat_stream_api(
             agent_id=self.agent_id,
             jwt_token=self.jwt_token,
             base_url=self.base_url,
@@ -153,12 +90,32 @@ class ChatClient:
             state=state,
             button_key=button_key,
             debug=debug
-        ):
+        )
+
+        for content, reasoning_content, chat_id, complete, finish in api_stream:
             if chat_id is not None:
                 self.chat_id = chat_id
-            elif content is not None:
-                yield content
 
+            # 处理推理内容
+            if reasoning_content:
+                yield {"type": "reasoning_token", "content": reasoning_content}
+
+            if content and not current_reply:
+                bubble_id_counter += 1
+                yield {"type": "start_bubble", "bubble_id": bubble_id_counter}
+            
+            if content:
+                current_reply += content
+                yield {"type": "token", "content": content}
+
+            if complete and current_reply.strip():
+                yield {"type": "end_bubble"}
+                current_reply = ""
+
+            if finish:
+                yield {"type": "finish"}
+                break
+                
     def history(self):
         """
         获取当前对话的历史记录
@@ -206,4 +163,4 @@ class ChatClient:
                 base_url=self.base_url,
                 chat_id=self.chat_id
             )
-        return []
\ No newline at end of file
+        return []
