@@ -1,7 +1,8 @@
 from .ChatClient import ChatClient
 from .KbClient import KbClient
+from .McpClient import MCPClient
 
-__all__ = ["ChatClient", "KbClient"]
+__all__ = ["ChatClient", "KbClient", "MCPClient"]
 
 
 def main() -> None:
